from cprint.main import cp, cf
from cprint.tools import demo as _demo
from cprint.tools import getshow_config as _showconfig

_cpshow = lambda : _showconfig(2)
_cpshoww = lambda : _showconfig(3)

config = tools = main = None
del config, tools, main